PyKernelLogit
===============

What is PyKernelLogit
*********************
PyKernelLogit is a Python package for performing maximum likelihood estimation
of conditional logit models and similar discrete choice models based on the
Python package PyLogit. This package extends the functionalities of PyLogit to
provide some functionalities that allows to estimate discrete choice models
based on Kernel Logistic Regression (KLR). Moreover, this package provides some
functions to estimate indicators such as the Willingness to Pay (WTP) for the
KLR models.


Installation
*********************
PyKernelLogit is available for its installation on the Python Package Index at:
https://pypi.org/project/pykernellogit/.


Authors
*********************
PyKernelLogit was developed by José Ángel Martín Baos from the University of
Castilla-La Mancha (JoseAngel.Martin@uclm.es) based on the package PyLogit 
(https://github.com/timothyb0912/pylogit)
developed by Timothy Brathwaite.

License
*********************
Modified BSD (3-clause)
